#
# spec file for package simutrans
#
# Copyright (c) 2020-2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pkgver 124-2-2
Name:           simutrans
Version:        124.2.2
Release:        1.1
Summary:        Transport and Economic Simulation Game
License:        Artistic-1.0
Group:          Amusements/Games/Strategy/Real Time
URL:            http://sourceforge.net/projects/simutrans/
Source0:        http://downloads.sourceforge.net/simutrans/simutrans-src-%{pkgver}.zip
Source1:        config.default
Source2:        http://www.simutrans.com/images/resources/simutrans-square.svg
# PATCH-FIX-UPSTREAM http://forum.simutrans.com/index.php?topic=11173.0
Patch0:         simutrans-fhs-home-directory.patch
Patch1:         simutrans-makefile.patch
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  unzip
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  freetype2-devel
%if 0%{?suse_version}
BuildRequires:  fdupes
BuildRequires:  update-desktop-files
%endif
BuildRequires:  dos2unix
BuildRequires:  hicolor-icon-theme
# Since now we have Leap > 15.4, we follow the advice here: https://forum.simutrans.com/index.php?action=post;quote=198369;topic=21320.0;last_msg=198369
BuildRequires:  fluidsynth-devel >= 2.1.0
Requires:       fluid-soundfont-gm
BuildRequires:  libzstd-devel
Recommends:     %{name}-pak128 >= 2.9.1
Suggests:       %{name}-pak128-german >= 2.2
Suggests:       %{name}-pak64 >= 124.2
Suggests:       %{name}-makeobj

%description
Simutrans is a transport and economic simulation with some ecological
aspects. The goal of the game is to build an infrastructure which
allows you to transport goods between the various industries and towns,
and to support the towns with water and energy. A second goal is to
become as rich as possible, but you will have to reinvest a good part
of your earned money to expand your infrastructure network.

%package makeobj
Summary:        Tool for compiling simutrans data packages
Group:          Development/Tools/Other
# Package was called simutrans previously
Obsoletes:      makeobj < %{version}-%{release}

%description makeobj
Makeobj is a easy to use software used to compile .dat files and .png pictures
to simutrans .pak files.

%prep
%autosetup -p1 -c -n simutrans

cp %{SOURCE1} .
# files with the wrong line-endings, which give a rpmlint warning:
#dos2unix simutrans/*.txt

%build
export CFLAGS="%{optflags}"
export CCFLAGS="$CFLAGS"
%make_build all makeobj
# The next 3 lines did not function correctly; so now we use the available theme pak files:
# cd themes.src
# sed -i 's|../makeobj|../../build/default/makeobj/makeobj|g' build_themes.sh
# ./build_themes.sh

%install
# Create starter-wrapper script (not a source so we can use directory macros):
mkdir -vp %{buildroot}%{_bindir}
cat > %{buildroot}%{_bindir}/%{name} << EOF
#!/bin/sh
cd %{_datadir}/%{name}
exec %{_libexecdir}/%{name}/sim -use_workdir \$@
EOF
chmod 755 %{buildroot}%{_bindir}/%{name}
# Install the executable "sim":
install -vDm755 build/default/sim %{buildroot}%{_libexecdir}/%{name}/sim
# Install makeobj, avoid conflict with makeobj from kdesdk-scripts
install -vm755 build/default/makeobj/makeobj %{buildroot}%{_libexecdir}/%{name}/makeobj
ln -s %{_libexecdir}/%{name}/makeobj %{buildroot}%{_bindir}/makeobj-simutrans
# Install data
mkdir -vp %{buildroot}%{_datadir}/%{name}
cp -va simutrans/* %{buildroot}%{_datadir}/%{name}
# Create dummy directories addons
mkdir -vp %{buildroot}%{_datadir}/%{name}/addons
# Move docs to the correct place
mkdir -vp %{buildroot}%{_docdir}/%{name}
mv -v %{buildroot}%{_datadir}/%{name}/*.txt %{buildroot}%{_docdir}/%{name}
# Install icon and .desktop file
install -vDm644 %{SOURCE2} %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%if 0%{?suse_version}
%suse_update_desktop_file -c simutrans "Simutrans" "Transportation Simulation Game" "simutrans" simutrans Game StrategyGame
%fdupes %{buildroot}%{_datadir}/%{name}
%endif

%files
%doc %{_docdir}/%{name}
%{_bindir}/%{name}
%{_datadir}/%{name}
%dir %{_libexecdir}/%{name}
%{_libexecdir}/%{name}/sim
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/applications/%{name}.desktop

%files makeobj
%{_bindir}/makeobj-simutrans
%dir %{_libexecdir}/%{name}
%{_libexecdir}/%{name}/makeobj

%changelog
* Wed Dec 11 2024 Michiel van der Wulp <michiel.vanderwulp@gmail.com> - 124-2-2
- update to version 124.2.2 (r11400 on 31-August-2024)
- See for more information about the 124.2.2 release:
  https://forum.simutrans.com/index.php/topic,23193.0.html
- In the words of prissi: "... There were even some ancient bugs unearthed with crossings
  and tiles with ways in cities and more. On Intel/AMD cpu's the memory footprint
  became 10%% smaller with some faster sync_step."
- Complete history can be found at (unofficial):
  https://github.com/simutrans/simutrans/blob/master/simutrans/history.txt
* Wed Jul 31 2024 Michiel van der Wulp <michiel.vanderwulp@gmail.com> - 124-2-1
- update to version 124.2.1 (r11351 on 20-July-2024)
- skipping update version 124.2
- See for more information about the 124.2 and the 124.2.1 releases:
  https://forum.simutrans.com/index.php/topic,23153.0.html
  https://forum.simutrans.com/index.php/topic,23162.0.html
- Summary by prissi:
  The version 124.2 started as another bugfix as there were
  many annoying bugs even in the 124.1. However, some additional
  change elevates this beyond a patch. Most are GUI improvements,
  like saving the windows now even with network games.
  The most dramatic change for a user is the new way builder.
  If a new way starts one tile from an existing way
  and ends one tile from an existing way, it will now try
  very hard to make a parallel track.
  It works as good as it can do without terraforming.
  It may still join at a place where it cannot pass next to it
  but then go parallel again, greatly saving efforts
  (especially with diagonals).
- Only for the 124.2, there is a README file with
  the list of changes at
  https://sourceforge.net/projects/simutrans/files/simutrans/124-2/README.txt/download
* Mon Jun  3 2024 Michiel van der Wulp <michiel.vanderwulp@gmail.com> - 124-1
- update to version 124.1
- This version mostly fixes bugs reported for previous version 124.0,
  with some features added to the top. There are also some changes related to packaging:
  1. The 124 release made Freetype a required dependency, but the build system
  was not updated to reflect that. As a result, you could compile Simutrans
  without Freetype, only for the game to fail at launch because
  it could not use any font. We have fixed this for the 124.1 release,
  and now Freetype is also required for building (except for server builds).
  2. The ".desktop" file has been renamed and moved to "src/linux/simutrans.desktop".
- See for more information about the 124.1 and the 124.0 releases:
  https://forum.simutrans.com/index.php/board,3.0.html
- Patch simutrans-makefile.patch added since GNU make version on OpenSuse 15.5 and 15.6
  does not support hashtags inside shell commands properly
  while the Gnu Make in Tumbleweed works correctly.
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Mon Jan 31 2022 Michiel van der Wulp <michiel.vanderwulp@gmail.com> - 123-0-1
- update to version 123.0.1
- This is a bugfix to 123.0, where the schedule editing did not really work.
- Also pak48, pak128, pak128.german and pak64.german got updates.
- This release is build from svn revision number 10421. This number is configured to allow
  network games to be able to connect to an online server running the same stable version.
- Complete history can be found at (unofficial):
  https://github.com/aburch/simutrans/blob/master/simutrans/history.txt
- From now on, the build is configured to use the zstd compression library for saving. Previously
  this was done with bzip2 compression, but zstd can replace it. Zstd is faster (advantage)
  but also leads to larger files (disadvantage). Usually network games using zstd, since speed is an issue.
  So for maximum network gaming compatibility, zstd is recommended.
- Drop upstream patch: patch-bugs.patch
* Mon Jan 10 2022 Michiel van der Wulp <michiel.vanderwulp@gmail.com> - 123-0
- update to version 123.0
- The most noticeable change will be the new GUI, which is now enforced in all dialogs.
  You can now also schedule convois with fixed departure times, if you want to play
  model railroad. Rivers now go from their source through lakes until the sea, and
  are shippable after passing a lake. Paks can be installed now ingame. There were
  of course also lot of bugfixes, not least thanks to the automatic testing.
- This release is build from svn revision number 10317.
- Added patch-bugs.patch
- Since the release contains some severe regression bugs, which were solved in the weeks after the release,
  the solutions were included here. See for the bugs:
  1: Map showing network: https://forum.simutrans.com/index.php/topic,21320.0.html
  2: The new setting  stop_halt_as_scheduled should be disabled by default:
  https://forum.simutrans.com/index.php/topic,21317.msg198325.html#msg198325
- Complete history can be found at (unofficial):
  https://github.com/aburch/simutrans/blob/master/simutrans/history.txt
* Sun Oct 11 2020 Michiel van der Wulp <michiel.vanderwulp@gmail.com> - 122-0
- update to version 122.0
- In the words of "prissi": It packed with new things hidden and in plain view.
  Like a much more stable server, optimisations for tablet usage and only games in lists,
  fast map creation, multi-tiled rotatable city buildings,
  better use of fixed monthly convoi costs, further improvement of the GUI, depot list,
  list of all existing vehicles, climates optional calculated from height and humidity
  and tons of bug fixes, also the scripted AI got rail support (still under optimisation).
- Complete history can be found at (unofficial):
  https://github.com/aburch/simutrans/blob/master/simutrans/history.txt
* Wed Oct  7 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Rename makeobj subpackage to simutrans-makeobj, and install the
  makeobj binary as /usr/bin/makeobj-simutrans, to avoid a conflict
  with makeobj from kdesdk-scripts.
- Cleanup spec file:
  * Remove unused allegro build dep
  * Remove no longer required __DATE__ mangling
  * Remove BuildRoot and defattr tags
* Fri Sep  4 2020 Matthias Mailänder <mailaender@opensuse.org>
- avoid using _service as it is forbidden in Factory
* Thu Dec  5 2019 Michiel van der Wulp <michiel.vanderwulp@gmail.com> - 121-0
- update to version 121-0
- Comletely overhauled GUI, which should scale much better with button and fontsize changes
- Larger citybuildings than 1x1 tile are now possible
- New signal type: Priority signals to facilitate overtaking of trains
- More details at (unofficial):
  https://github.com/aburch/simutrans/blob/master/simutrans/history.txt
* Tue Sep 25 2018 Michiel van der Wulp <michiel.vanderwulp@gmail.com>
- update to version 120-4-1 - changes described at
  https://forum.simutrans.com/index.php/topic,18515.0.html
  or more in detail (unofficial):
  https://github.com/aburch/simutrans/blob/master/simutrans/history.txt
* Wed Sep 19 2018 Michiel van der Wulp <michiel.vanderwulp@gmail.com>
- update to version 120-4 - changes described at
  https://forum.simutrans.com/index.php/topic,18499.0.html
  or more in detail (unofficial):
  https://github.com/aburch/simutrans/blob/master/simutrans/history.txt
* Fri Sep  7 2018 michiel.vanderwulp@gmail.com
- update to version 120-3 - changes described at
  https://forum.simutrans.com/index.php/topic,18295.0.html
  or more in detail (unofficial):
  https://github.com/aburch/simutrans/blob/master/simutrans/history.txt
* Fri Mar 31 2017 michiel.vanderwulp@gmail.com
- update to version 120.2.2 - changes described at
  http://forum.simutrans.com/index.php?topic=16909.0
* Wed Mar 22 2017 rpm@fthiessen.de
- Build with sdl2
- Added makeobj subpackages (makeobj is used to compile data and
  images for custom graphic packs).
- Use https://en.opensuse.org/SourceUrls
- Some spec file cleanup
* Tue Mar 21 2017 michiel.vanderwulp@gmail.com
- update to version 120.2.1 - changes described at
  http://forum.simutrans.com/index.php?topic=16798.0
- skipped version 120.2 - changes described at
  http://forum.simutrans.com/index.php?topic=16680.0
* Thu Feb  4 2016 michiel.vanderwulp@gmail.com
- update to version 120.1.3 - changes described at
  http://forum.simutrans.com/index.php?topic=15226.0
* Fri Jan  1 2016 michiel.vanderwulp@gmail.com
- update to version 120.1.1
* Sat Mar 14 2015 michiel.vanderwulp@gmail.com
- update to version 120.0.1
* Thu Feb 20 2014 michiel.vanderwulp@gmail.com
- update to version 112.3
- added folders only supplied with the binary
* Thu Dec 27 2012 mailaender@opensuse.org
- actually build from source, not copy prebuild binaries
- update to version 112.1
- move content to separate packages
- adhere to FHS
- added .desktop file and icon
* Wed Dec 26 2012 joop.boonen@opensuse.org
- Build for all architectures
- Corrected Url and license
* Fri Mar 23 2012 jengelh@medozas.de
- Parallel build with %%_smp_mflags; strip redundant sections/tags
* Fri Jan  9 2009 olh@suse.de
- use ExclusiveArch as in /SRC/arch/
* Thu Mar 29 2007 coolo@suse.de
- fix BuildRequires
* Fri Aug  4 2006 lmichnovic@suse.cz
- fixed wrong encoding of sk translation file
* Fri Aug  4 2006 lmichnovic@suse.cz
- update of the binary to version 0.88.10.5
- update of the data pack to version 1.3.1
  - new translations: dk, nl, pl, sk
  - many fixes (e.g. pricing, costs, typos) and improvements (new
    vehicles, new buildings, monorail improvements)
  - fixed some copyright information
* Fri Jun 16 2006 lmichnovic@suse.cz
- update of the binary to version 0.88.6
- update of the data pack to version 1.2.9d
  - many improvements and fixes to buildings and vehicles
  - aeroplanes was added
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 lmichnovic@suse.cz
- update to 0.88.01 version :
  has smoother and nicer graphics because of use 128x128 pixel
  objects instead 64x64 in previous version
- added extensions fertilizer, czech-vehicles
* Mon Aug 11 2003 ltinkl@suse.cz
- fixed wrong file permissions [#28646]
* Fri Dec 13 2002 prehak@suse.cz
- updated to version 0.81.0 (sources not available anymore)
* Mon Jul  8 2002 prehak@suse.cz
- updated to version 0.80.0
- added midi files with music
- added winter scenario graphics (created README)
* Wed Nov 21 2001 rvasice@suse.cz
- fixed permissions for start script
* Mon Nov 19 2001 rvasice@suse.cz
- initial package release (version 0.79.0)
